Learn R Programming

torchaudio (version 0.1.1.0)

speechcommand_dataset: Speech Commands Dataset

Description

Speech Commands Dataset

Usage

speechcommand_dataset(
  root,
  url = "speech_commands_v0.02",
  folder_in_archive = "SpeechCommands",
  download = FALSE
)

Arguments

root

(str): Path to the directory where the dataset is found or downloaded.

url

(str, optional): The URL to download the dataset from, or the type of the dataset to dowload. Allowed type values are "speech_commands_v0.01" and "speech_commands_v0.02" (default: "speech_commands_v0.02")

folder_in_archive

(str, optional): The top-level directory of the dataset. (default: "SpeechCommands")

download

(bool, optional): Whether to download the dataset if it is not found at root path. (default: FALSE).

Value

a torch::dataset()