transform_timemasking: Time-domain Masking
Description
Apply masking to a spectrogram in the time domain.
Usage
transform_timemasking(time_mask_param, iid_masks)
Arguments
time_mask_param
(int): maximum possible length of the mask.
Indices uniformly sampled from [0, time_mask_param).
iid_masks
(bool, optional): whether to apply different masks to each
example/channel in the batch. (Default: FALSE)
This option is applicable only when the input tensor is 4D.
Value
not implemented yet.