Speech Commands Dataset
speechcommand_dataset(
root,
url = "speech_commands_v0.02",
folder_in_archive = "SpeechCommands",
download = FALSE
)(str): Path to the directory where the dataset is found or downloaded.
(str, optional): The URL to download the dataset from,
or the type of the dataset to dowload.
Allowed type values are "speech_commands_v0.01" and "speech_commands_v0.02"
(default: "speech_commands_v0.02")
(str, optional): The top-level directory of the dataset. (default: "SpeechCommands")
(bool, optional): Whether to download the dataset if it is not found at root path. (default: FALSE).
a torch::dataset()